@@ -1167,8 +1167,9 @@ def livebox_info():
     else:
         o = result['status']
         print("%20s : %s" % ("SoftwareVersion", o['SoftwareVersion']))
-        print("%20s : %s  (NumberOfReboots: %s)" % ("UpTime", str(datetime.timedelta(seconds=int(o['UpTime']))), o['NumberOfReboots']))
-        print("%20s : %s" % ("ExternalIPAddress", o['ExternalIPAddress']))
+        #print("%20s : %s  (NumberOfReboots: %s)" % ("UpTime", str(datetime.timedelta(seconds=int(o.get('UpTime',0)))), o['NumberOfReboots']))
+        #print("%20s : %s" % ("ExternalIPAddress", o['ExternalIPAddress']))
+        exit()
 
         # pas d'objet Devices dans la Livebox 2
         result = requete("Devices.Device.lan:getFirstParameter", { "parameter": "IPAddress" }, silent=True)
@@ -1406,7 +1407,7 @@ def add_commands(parser):
                 if mac_parser is None:
                     s = "%-18s %-15s %c %-35s %s" % (host['MACAddress'], host['InterfaceType'], actif, host['HostName'], host['IPAddress'])
                 else:
-                    s = "%-18s %-12s %-15s %c %-35s %s" % (host['MACAddress'], mac_parser.get_manuf(host['MACAddress']), host['InterfaceType'], actif, host['HostName'], host['IPAddress'])
+                    s = "%-18s %-12s %-15s %c %-35s %s" % (host['MACAddress'], mac_parser.get_manuf(host['MACAddress']), host.get('InterfaceType', ""), actif, host['HostName'], host['IPAddress'])
                 print(s)
 
     #
